#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/openldap/ldap.conf.new

( cd usr/bin ; rm -rf ldapadd )
( cd usr/bin ; ln -sf ldapmodify ldapadd )
( cd usr/lib ; rm -rf libldap_r-2.3.so.0 )
( cd usr/lib ; ln -sf libldap_r-2.3.so.0.2.20 libldap_r-2.3.so.0 )
( cd usr/lib ; rm -rf libldap-2.3.so.0 )
( cd usr/lib ; ln -sf libldap-2.3.so.0.2.20 libldap-2.3.so.0 )
( cd usr/lib ; rm -rf libldap_r.so )
( cd usr/lib ; ln -sf libldap_r-2.3.so.0.2.20 libldap_r.so )
( cd usr/lib ; rm -rf liblber-2.3.so.0 )
( cd usr/lib ; ln -sf liblber-2.3.so.0.2.20 liblber-2.3.so.0 )
( cd usr/lib ; rm -rf liblber.so )
( cd usr/lib ; ln -sf liblber-2.3.so.0.2.20 liblber.so )
( cd usr/lib ; rm -rf libldap.so )
( cd usr/lib ; ln -sf libldap-2.3.so.0.2.20 libldap.so )
( cd usr/man/man1 ; rm -rf ldapadd.1.gz )
( cd usr/man/man1 ; ln -sf ldapmodify.1.gz ldapadd.1.gz )
( cd usr/man/man3 ; rm -rf ldap_bind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_bind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_values.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_count_values.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2matchingrule.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2matchingrule.3.gz )
( cd usr/man/man3 ; rm -rf ld_errno.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ld_errno.3.gz )
( cd usr/man/man3 ; rm -rf ldap_attributetype_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_attributetype_free.3.gz )
( cd usr/man/man3 ; rm -rf ber_first_element.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_first_element.3.gz )
( cd usr/man/man3 ; rm -rf ldap_objectclass2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_objectclass2name.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_enum.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_enum.3.gz )
( cd usr/man/man3 ; rm -rf ldap_url_parse.3.gz )
( cd usr/man/man3 ; ln -sf ldap_url.3.gz ldap_url_parse.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_int.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_int.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sort_entries.3.gz )
( cd usr/man/man3 ; ln -sf ldap_sort.3.gz ldap_sort_entries.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2dn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_str2dn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sasl_bind.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_sasl_bind.3.gz )
( cd usr/man/man3 ; rm -rf ldap_add_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_add.3.gz ldap_add_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_msgfree.3.gz )
( cd usr/man/man3 ; ln -sf ldap_result.3.gz ldap_msgfree.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sort_values.3.gz )
( cd usr/man/man3 ; ln -sf ldap_sort.3.gz ldap_sort_values.3.gz )
( cd usr/man/man3 ; rm -rf ldap_delete_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sasl_bind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_sasl_bind_s.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_null.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_null.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modify_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_modify_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_attributetype2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_attributetype2name.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2syntax.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2syntax.3.gz )
( cd usr/man/man3 ; rm -rf ldap_abandon_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_abandon.3.gz ldap_abandon_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_add_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_add.3.gz ldap_add_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_objectclass2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_objectclass2str.3.gz )
( cd usr/man/man3 ; rm -rf ber_skip_tag.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_skip_tag.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_st.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_st.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_ostring.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_ostring.3.gz )
( cd usr/man/man3 ; rm -rf ldap_matchingrule_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_matchingrule_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2attributetype.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2attributetype.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dcedn2dn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dcedn2dn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2ad_canonical.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2ad_canonical.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modify_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_modify_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_reference.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_reference.3.gz ldap_next_reference.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_string.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_string.3.gz )
( cd usr/man/man3 ; rm -rf ber_str2bv.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_str2bv.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvfree.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvfree.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_next.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_next.3.gz )
( cd usr/man/man3 ; rm -rf ldap_perror.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_perror.3.gz )
( cd usr/man/man3 ; rm -rf ldap_free_urldesc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_url.3.gz ldap_free_urldesc.3.gz )
( cd usr/man/man3 ; rm -rf ber_scanf.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_scanf.3.gz )
( cd usr/man/man3 ; rm -rf ldap_parse_sasl_bind_result.3.gz )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3.gz ldap_parse_sasl_bind_result.3.gz )
( cd usr/man/man3 ; rm -rf ldap_simple_bind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_simple_bind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_matchingrule2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_matchingrule2name.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_bitstring.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_bitstring.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvstrdup.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvstrdup.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_s.3.gz )
( cd usr/man/man3 ; rm -rf ber_dupbv.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_dupbv.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_entry.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_entry.3.gz ldap_next_entry.3.gz )
( cd usr/man/man3 ; rm -rf ldap_matchingrule2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_matchingrule2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_errlist.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_errlist.3.gz )
( cd usr/man/man3 ; rm -rf ber_free.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_free.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_enum.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_enum.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvarray_free.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvarray_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modrdn2_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3.gz ldap_modrdn2_s.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_boolean.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_boolean.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modrdn_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3.gz ldap_modrdn_s.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_null.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_null.3.gz )
( cd usr/man/man3 ; rm -rf ber_peek_tag.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_peek_tag.3.gz )
( cd usr/man/man3 ; rm -rf ldap_value_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_value_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_compare_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_compare.3.gz ldap_compare_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_delete_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2ufn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2ufn.3.gz )
( cd usr/man/man3 ; rm -rf ber_next_element.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_next_element.3.gz )
( cd usr/man/man3 ; rm -rf ldap_syntax2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_syntax2str.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_stringa.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_stringa.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_stringb.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_stringb.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modrdn2.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3.gz ldap_modrdn2.3.gz )
( cd usr/man/man3 ; rm -rf ldap_explode_rdn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_explode_rdn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_compare_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_compare.3.gz ldap_compare_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_mods_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_mods_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_result2error.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_result2error.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2objectclass.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2objectclass.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sort_strcasecmp.3.gz )
( cd usr/man/man3 ; ln -sf ldap_sort.3.gz ldap_sort_strcasecmp.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_scherr2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_scherr2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_references.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_reference.3.gz ldap_count_references.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_attribute.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_attribute.3.gz ldap_next_attribute.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvarray_add.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvarray_add.3.gz )
( cd usr/man/man3 ; rm -rf ldap_value_free_len.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_value_free_len.3.gz )
( cd usr/man/man3 ; rm -rf ldap_simple_bind.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_simple_bind.3.gz )
( cd usr/man/man3 ; rm -rf ldap_delete_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ber_alloc_t.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_alloc_t.3.gz )
( cd usr/man/man3 ; rm -rf ldap_attributetype2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_attributetype2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_parse_extended_result.3.gz )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3.gz ldap_parse_extended_result.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_seq.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_seq.3.gz )
( cd usr/man/man3 ; rm -rf ldap_err2string.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_err2string.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_is_ldap_url.3.gz )
( cd usr/man/man3 ; ln -sf ldap_url.3.gz ldap_is_ldap_url.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_set.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_set.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvstr.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvstr.3.gz )
( cd usr/man/man3 ; rm -rf ldap_get_values_len.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_get_values_len.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2dcedn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2dcedn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_msgid.3.gz )
( cd usr/man/man3 ; ln -sf ldap_result.3.gz ldap_msgid.3.gz )
( cd usr/man/man3 ; rm -rf ldap_explode_dn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_explode_dn.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvecadd.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvecadd.3.gz )
( cd usr/man/man3 ; rm -rf ldap_syntax_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_syntax_free.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvdup.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvdup.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_message.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_message.3.gz ldap_next_message.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_entries.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_entry.3.gz ldap_count_entries.3.gz )
( cd usr/man/man3 ; rm -rf ldap_init.3.gz )
( cd usr/man/man3 ; ln -sf ldap_open.3.gz ldap_init.3.gz )
( cd usr/man/man3 ; rm -rf ber_start_set.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_start_set.3.gz )
( cd usr/man/man3 ; rm -rf ber_printf.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_printf.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_messages.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_message.3.gz ldap_count_messages.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_int.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_int.3.gz )
( cd usr/man/man3 ; rm -rf ldap_msgtype.3.gz )
( cd usr/man/man3 ; ln -sf ldap_result.3.gz ldap_msgtype.3.gz )
( cd usr/man/man3 ; rm -rf ldap_add_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_add.3.gz ldap_add_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_objectclass_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_objectclass_free.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvecfree.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvecfree.3.gz )
( cd usr/man/man3 ; rm -rf ber_flush.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_flush.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_values_len.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_count_values_len.3.gz )
( cd usr/man/man3 ; rm -rf ldap_syntax2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_syntax2name.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modify_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_modify_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_compare_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_compare.3.gz ldap_compare_s.3.gz )
